#!/bin/sh
#
# Licensed to the Apache Software Foundation (ASF) under one or more
# contributor license agreements.  See the NOTICE file distributed with
# this work for additional information regarding copyright ownership.
# The ASF licenses this file to You under the Apache License, Version 2.0
# (the "License"); you may not use this file except in compliance with
# the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
#
# Apache control script designed to allow an easy command line interface
# to controlling Apache.  Written by Marc Slemko, 1997/08/23
# 
# The exit codes returned are:
#   XXX this doc is no longer correct now that the interesting
#   XXX functions are handled by httpd
#	0 - operation completed successfully
#	1 - 
#	2 - usage error
#	3 - httpd could not be started
#	4 - httpd could not be stopped
#	5 - httpd could not be started during a restart
#	6 - httpd could not be restarted during a restart
#	7 - httpd could not be restarted during a graceful restart
#	8 - configuration syntax error
#
# When multiple arguments are given, only the error from the _last_
# one is reported.  Run "apachectl help" for usage info
#

ARGV="$@"
#
# |||||||||||||||||||| START CONFIGURATION SECTION  ||||||||||||||||||||
# --------------------                              --------------------
# 
# the path to your httpd binary, including options if necessary
HTTPD='/usr/local/AppCentral/httpd-2.4.43/data/binary/sbin/apache2'
PIDFILE='/usr/local/AppCentral/httpd-2.4.43/data/var/run/apache2/httpd.pid'
#
# pick up any necessary environment variables
if test -f /usr/local/AppCentral/httpd-2.4.43/data/conf/envvars; then
  . /usr/local/AppCentral/httpd-2.4.43/data/conf/envvars
fi
#
# a command that outputs a formatted text version of the HTML at the
# url given on the command line.  Designed for lynx, however other
# programs may work.  
#LYNX="lynx -dump"
#
# the URL to your server's mod_status status page.  If you do not
# have one, then status and fullstatus will not work.
#STATUSURL="http://localhost:80/server-status"
#
# Set this variable to a command that increases the maximum
# number of file descriptors allowed per child process. This is
# critical for configurations that use many file descriptors,
# such as mass vhosting, or a multithreaded server.
ULIMIT_MAX_FILES="ulimit -S -n `ulimit -H -n`"
# --------------------                              --------------------
# ||||||||||||||||||||   END CONFIGURATION SECTION  ||||||||||||||||||||

# Set the maximum number of file descriptors allowed per child process.
if [ "x$ULIMIT_MAX_FILES" != "x" ] ; then
    $ULIMIT_MAX_FILES
fi

ERROR=0
if [ "x$ARGV" = "x" ] ; then 
    ARGV="-h"
fi

# If PIDFILE exists, get the pid.
if [ -f $PIDFILE ]; then
	pid=`cat $PIDFILE`
fi

if [ ! -x $HTTPD ]; then
	echo "$0: $HTTPD: cannot execute"
	exit 1
fi

AS_CONF="/usr/local/AppCentral/httpd-2.4.43/data/conf/asustor.conf"

# Asustor check Apache2 service if enabled
EnableHttp=`/usr/bin/confutil -get $AS_CONF "Web Center" EnableHttp`
EnableHttps=`/usr/bin/confutil -get $AS_CONF "Web Center" EnableHttps`
Package=`/usr/bin/confutil -get $AS_CONF "Web Center" apache`

case $ARGV in

  start)
	echo "Starting Web Server..."
	export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:/usr/builtin/lib
	if [ "$EnableHttp" = "No" ] && [ "$EnableHttps" = "No" ]; then
		echo "Web Server isn't enabled, can't start service"
		exit 0
	fi
	if [ "$Package" = "httpd-2.4.43" ]; then
		$HTTPD -k start
	fi
	;;

  stop)
	;;

  restart)
	;;

  *)
	echo "usage: $0 {start|stop|restart}"
	exit 1
	;;

esac

exit 0
